@@ -22,8 +22,7 @@ sub read_file_content {
     my $charset = Dancer::Config::setting('charset');
 
     my $open_flag = '<';
-    $open_flag = '<:encoding(UTF-8)' 
-        if lc($charset) eq 'utf-8' or lc($charset) eq 'utf8';
+    $open_flag = '<:encoding(UTF-8)' if $charset eq 'UTF-8';
     if ($file && open($fh, $open_flag, $file)) {
         return read_glob_content($fh);
     }
@@ -37,7 +36,7 @@ sub read_glob_content {
 
     # we don't want to do that as we'll encode the stuff later
     # binmode $fh;
-    
+
     my @content = <$fh>;
     close $fh;
     my $content = join("", @content);
@@ -101,9 +100,9 @@ in case it failed to open the file.
     open my $fh, '<', $file or die "$!\n";
     my $content = read_glob_content($fh);
 
-Same as I<read_file_content>, only it accepts a file handler.
+Same as I<read_file_content>, only it accepts a file handle.
 
-Returns the content and B<closes the file handler>.
+Returns the content and B<closes the file handle>.
 
 =head1 EXPORT
 
